class Calculator:
    def __init__(self,num1,num2):
        self.num1 = num1
        self.num2 = num2

    def add(self):
        r = self.num1 + self.num2
        result = (
            "The sum of " + str(self.num1) + " and " + str(self.num2) + " is " + str(r)
        )
        #print(result)
        return result

    def subtract(self):
        r = self.num1 - self.num2
        result = (
            "The difference of "
            + str(self.num1)
            + " and "
            + str(self.num2)
            + " is "
            + str(r)
        )
        #print(result)
        return result

    def multiply(self):
        r = self.num1 * self.num2
        result = (
            "The product of "
            + str(self.num1)
            + " and "
            + str(self.num2)
            + " is "
            + str(r)
        )
        #print(result)
        return result

    def divide(self):
        r = self.num1 / self.num2
        result = (
            "The quotient when "
            + str(self.num1)
            + " is divided by "
            + str(self.num2)
            + " is "
            + str(r)
        )
        #print(result)
        return result


from flask import Flask, render_template, request
from custom_calc_sdp.mycalculator import Calculator
import webbrowser
from threading import Timer

app = Flask(__name__)

EXPLAIN_TEMPLATE_LOADING = True

@app.route("/", methods=["GET", "POST"])  # To render Homepage
def home_page():
    return render_template("index.html")


@app.route("/math", methods=["POST"])  # This will be called from UI
def math_operation():
    if request.method == "POST":
        operation = request.form["operation"]
        num1 = int(request.form["num1"])
        num2 = int(request.form["num2"])
        calc = Calculator(num1, num2)
        result=""
        if operation == "add":
            r = calc.add()
            result = "the sum of " + str(num1) + " and " + str(num2) + " is " + str(r)
        if operation == "subtract":
            r = calc.subtract()
            result = (
                    "the difference of " + str(num1) + " and " + str(num2) + " is " + str(r)
            )
        if operation == "multiply":
            r = calc.multiply()
            result = (
                    "the product of " + str(num1) + " and " + str(num2) + " is " + str(r)
            )
        if operation == "divide":
            r = calc.divide()
            result = (
                    "the quotient when "
                    + str(num1)
                    + " is divided by "
                    + str(num2)
                    + " is "
                    + str(r)
            )
        return render_template("results.html", result=result)


def open_browser():
    webbrowser.open_new('http://127.0.0.1:8080/')


def start_app():
    Timer(1, open_browser).start()
    app.run(host="127.0.0.1", port=8080,debug=True)


if __name__ == "__main__":
    start_app()



from setuptools import find_packages, setup

setup(
  name = 'custom_calc_sdp',
  packages = find_packages(),
  include_package_data=True,
  version = '0.1',
  license='MIT',
  description = 'Simple Arithmetic Calculator',
  author = 'Subhradipta Paul',
  author_email = 'paulsubhradipta@gmail.com',
  keywords = ['calculator'],
  install_requires=[
          'flask',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',

    # Indicate who your project is intended for
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',

    # Pick your license as you wish
    'License :: OSI Approved :: MIT License',

    # Specify the Python versions you support here. In particular, ensure
    # that you indicate whether you support Python 2, Python 3 or both.
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
  entry_points={
        "console_scripts": [
            "calc = custom_calc_sdp.app:start_app",
        ]},
)
